==> packageinstaller-pkglist_0.3.29.tar.xz: packageinstaller-pkglist/wicd.pm <==
<?xml version="1.0"?>
<app>

<category>
Network
</category>

<name>
wicd
</name>

<description>
   <am>Lightweight general-purpose network configuration server</am>
   <ar>Lightweight general-purpose network configuration server</ar>
   <be>Lightweight general-purpose network configuration server</be>
   <bg>Lightweight general-purpose network configuration server</bg>
   <bn>Lightweight general-purpose network configuration server</bn>
   <ca>Lightweight general-purpose network configuration server</ca>
   <cs>Lightweight general-purpose network configuration server</cs>
   <da>Lightweight general-purpose network configuration server</da>
   <de>Allzweck Netzwerk-Konfigurationsserver in Leichtbauweise</de>
   <el>Ελαφρύς διακομιστής διαμόρφωσης δικτύου γενικής χρήσης</el>
   <en>Lightweight general-purpose network configuration server</en>
   <es_ES>Lightweight general-purpose network configuration server</es_ES>
   <es>Servidor de configuración de red ligero de uso general</es>
   <et>Lightweight general-purpose network configuration server</et>
   <eu>Lightweight general-purpose network configuration server</eu>
   <fa>Lightweight general-purpose network configuration server</fa>
   <fil_PH>Lightweight general-purpose network configuration server</fil_PH>
   <fi>Lightweight general-purpose network configuration server</fi>
   <fr_BE>Lightweight general-purpose network configuration server</fr_BE>
   <fr>Serveur de configuration réseau léger et polyvalent</fr>
   <gl_ES>Lightweight general-purpose network configuration server</gl_ES>
   <he_IL>Lightweight general-purpose network configuration server</he_IL>
   <hi>Lightweight general-purpose network configuration server</hi>
   <hr>Lightweight general-purpose network configuration server</hr>
   <hu>Lightweight general-purpose network configuration server</hu>
   <id>Lightweight general-purpose network configuration server</id>
   <is>Lightweight general-purpose network configuration server</is>
   <it>Lightweight general-purpose network configuration server</it>
   <ja>軽量な汎用ネットワーク設定サーバー</ja>
   <kk>Lightweight general-purpose network configuration server</kk>
   <ko>Lightweight general-purpose network configuration server</ko>
   <lt>Lightweight general-purpose network configuration server</lt>
   <mk>Lightweight general-purpose network configuration server</mk>
   <mr>Lightweight general-purpose network configuration server</mr>
   <nb_NO>Lightweight general-purpose network configuration server</nb_NO>
   <nb>Lettvektig tjener for generelt nettverksoppsett</nb>
   <nl_BE>Lightweight general-purpose network configuration server</nl_BE>
   <nl>Lightweight general-purpose network configuration server</nl>
   <pl>Lightweight general-purpose network configuration server</pl>
   <pt_BR>Servidor de configuração de rede leve e de uso geral</pt_BR>
   <pt>Lightweight general-purpose network configuration server</pt>
   <ro>Lightweight general-purpose network configuration server</ro>
   <ru>Lightweight general-purpose network configuration server</ru>
   <sk>Lightweight general-purpose network configuration server</sk>
   <sl>Lightweight general-purpose network configuration server</sl>
   <sq>Lightweight general-purpose network configuration server</sq>
   <sr>Lightweight general-purpose network configuration server</sr>
   <sv>Lättvikts nätverkskonfigurations-server för alla ändamål</sv>
   <th>Lightweight general-purpose network configuration server</th>
   <tr>Lightweight general-purpose network configuration server</tr>
   <uk>Lightweight general-purpose network configuration server</uk>
   <vi>Lightweight general-purpose network configuration server</vi>
   <zh_CN>Lightweight general-purpose network configuration server</zh_CN>
   <zh_HK>Lightweight general-purpose network configuration server</zh_HK>
   <zh_TW>Lightweight general-purpose network configuration server</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
wicd
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
wicd
</uninstall_package_names>
</app>

==> packageinstaller-pkglist_0.3.32.tar.xz: packageinstaller-pkglist/wicd.pm <==
<?xml version="1.0"?>
<app>

<category>
Network
</category>

<name>
wicd
</name>

<description>
   <am>Lightweight general-purpose network configuration server</am>
   <ar>Lightweight general-purpose network configuration server</ar>
   <be>Lightweight general-purpose network configuration server</be>
   <bg>Lightweight general-purpose network configuration server</bg>
   <bn>Lightweight general-purpose network configuration server</bn>
   <ca>Lightweight general-purpose network configuration server</ca>
   <cs>Lightweight general-purpose network configuration server</cs>
   <da>Lightweight general-purpose network configuration server</da>
   <de>Allzweck Netzwerk-Konfigurationsserver in Leichtbauweise</de>
   <el>Ελαφρύς διακομιστής διαμόρφωσης δικτύου γενικής χρήσης</el>
   <en>Lightweight general-purpose network configuration server</en>
   <es_ES>Servidor de configuración de red ligero de uso general</es_ES>
   <es>Servidor de configuración de red ligero de uso general</es>
   <et>Lightweight general-purpose network configuration server</et>
   <eu>Lightweight general-purpose network configuration server</eu>
   <fa>Lightweight general-purpose network configuration server</fa>
   <fil_PH>Lightweight general-purpose network configuration server</fil_PH>
   <fi>Kevyt yleiskäyttöinen verkon konfigurointipalvelin</fi>
   <fr_BE>Lightweight general-purpose network configuration server</fr_BE>
   <fr>Serveur de configuration réseau léger et polyvalent</fr>
   <gl_ES>Lightweight general-purpose network configuration server</gl_ES>
   <gu>Lightweight general-purpose network configuration server</gu>
   <he_IL>Lightweight general-purpose network configuration server</he_IL>
   <hi>Lightweight general-purpose network configuration server</hi>
   <hr>Lightweight general-purpose network configuration server</hr>
   <hu>Lightweight general-purpose network configuration server</hu>
   <id>Lightweight general-purpose network configuration server</id>
   <is>Lightweight general-purpose network configuration server</is>
   <it>Server per le configurazioni di rete, leggero, per uso generico</it>
   <ja>軽量な汎用ネットワーク設定サーバー</ja>
   <kk>Lightweight general-purpose network configuration server</kk>
   <ko>Lightweight general-purpose network configuration server</ko>
   <lt>Lightweight general-purpose network configuration server</lt>
   <mk>Lightweight general-purpose network configuration server</mk>
   <mr>Lightweight general-purpose network configuration server</mr>
   <nb_NO>Lightweight general-purpose network configuration server</nb_NO>
   <nb>Lettvektig tjener for generelt nettverksoppsett</nb>
   <nl_BE>Lightweight general-purpose network configuration server</nl_BE>
   <nl>Lightweight general-purpose network configuration server</nl>
   <pl>Lightweight general-purpose network configuration server</pl>
   <pt_BR>Servidor de configuração de rede leve e de uso geral</pt_BR>
   <pt>Gestor genérico leve configuração de servidores de rede</pt>
   <ro>Lightweight general-purpose network configuration server</ro>
   <ru>Lightweight general-purpose network configuration server</ru>
   <sk>Lightweight general-purpose network configuration server</sk>
   <sl>Lightweight general-purpose network configuration server</sl>
   <sq>Lightweight general-purpose network configuration server</sq>
   <sr>Lightweight general-purpose network configuration server</sr>
   <sv>Lättvikts nätverkskonfigurations-server för alla ändamål</sv>
   <th>Lightweight general-purpose network configuration server</th>
   <tr>Lightweight general-purpose network configuration server</tr>
   <uk>Lightweight general-purpose network configuration server</uk>
   <vi>Lightweight general-purpose network configuration server</vi>
   <zh_CN>Lightweight general-purpose network configuration server</zh_CN>
   <zh_HK>Lightweight general-purpose network configuration server</zh_HK>
   <zh_TW>Lightweight general-purpose network configuration server</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
wicd
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
wicd
</uninstall_package_names>
</app>
